@@ -111,14 +111,14 @@ def _get_one_batch_after_timestamp(consumer, latest_timestamp):
     return batch, metadata["timestamp"], metadata['file_name'], metadata
     
 
-def start_processor(process, consumer): 
-    latest_timestamp = _get_latest_processed_timestamp(consumer)
+def start_processor(process, consumer='matching', data_source='main-foodProject'):
+    latest_timestamp = _get_latest_processed_timestamp(f'{consumer}-{data_source}')  # from state
     while True:
         print('latest_timestamp before : ', latest_timestamp)
-        batch, latest_timestamp, file_name, metadata = _get_one_batch_after_timestamp(consumer, latest_timestamp)
+        batch, latest_timestamp, file_name, metadata = _get_one_batch_after_timestamp(data_source, latest_timestamp)
         print('latest_timestamp after : ', latest_timestamp)
         if batch is None:
             print("batch is None")
             return
         process(batch, latest_timestamp, file_name, metadata)
-        _update_latest_processed_timestamp(consumer, latest_timestamp)
+        _update_latest_processed_timestamp(f'{consumer}-{data_source}', latest_timestamp)
